@@ -218,7 +218,7 @@ class PyGauge(wx.Window):
     def GetBarGradient(self):
         """ Returns a tuple containing the gradient start and end colours. """
 
-        if self._barGradient == None:
+        if self._barGradient is None:
             return None
 
         return self._barGradient[0]
@@ -344,7 +344,7 @@ class PyGauge(wx.Window):
                 c1,c2 = gradient
                 w = rect.width * (float(self._valueSorted[i]) / self._range)
                 r = copy.copy(rect)
-                r.width = w
+                r.width = int(w)
                 dc.GradientFillLinear(r, c1, c2, wx.EAST)
         else:
             for i, colour in enumerate(self._barColourSorted):
@@ -352,7 +352,7 @@ class PyGauge(wx.Window):
                 dc.SetPen(wx.Pen(colour))
                 w = rect.width * (float(self._valueSorted[i]) / self._range)
                 r = copy.copy(rect)
-                r.width = w
+                r.width = int(w)
                 dc.DrawRectangle(r)
 
 
